# ExternalAPIWaybillRowRequest


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**assortment_id** | **str** | The external ID of the assortment. Usually &#x60;null&#x60; if waybill was created in Waybiller UI and not over Waybiller External API. | [optional] 
**assortment_raw_id** | **int** | The ID of the assortment. | [optional] 
**assortment_name** | **str** | The name of the assortment. | [optional] 
**dispatched_amount** | **decimal.Decimal** | Dispatched material amount | [optional] 
**subset_object_raw_id** | **int** | The ID of the subset of the assortment. | [optional] 
**extra_information_long** | **str** |  | [optional] 
**extra_information_short** | **str** |  | [optional] 

## Example

```python
from openapi_client.models.external_api_waybill_row_request import ExternalAPIWaybillRowRequest

# TODO update the JSON string below
json = "{}"
# create an instance of ExternalAPIWaybillRowRequest from a JSON string
external_api_waybill_row_request_instance = ExternalAPIWaybillRowRequest.from_json(json)
# print the JSON string representation of the object
print(ExternalAPIWaybillRowRequest.to_json())

# convert the object into a dict
external_api_waybill_row_request_dict = external_api_waybill_row_request_instance.to_dict()
# create an instance of ExternalAPIWaybillRowRequest from a dict
external_api_waybill_row_request_from_dict = ExternalAPIWaybillRowRequest.from_dict(external_api_waybill_row_request_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


